# seclibb

`seclibb` is a [1secmail]("https://1secmail.com") library 

## How To install seclibb

You Can Install seclib By typing: `pip install seclib`

## Example

```
1. import seclibb
2. sl = seclibb.seclibb()
3. email = sl.generate_email()
4. print(email)
```